<?php
$lang['info_detail_returnid'] = 'This preference is used to determine a page (and therefore a template) to use to view detail pages.  Individualized News Detail URLS will not work if this parameter is not set to a valid page.  Additionally, if this preference is set, and no detailpage parameter is provided on the news tag, then this value will be used for detail links';
$lang['title_detail_returnid'] = 'Default page to use for detail views';
$lang['title_submission_settings'] = 'News Submission Settings';
$lang['title_fesubmit_settings'] = 'Frontend Submit Settings';
$lang['title_notification_settings'] = '&Eacute;rtes&iacute;t&eacute;s be&aacute;ll&iacute;t&aacute;sok';
$lang['title_detail_settings'] = 'Detail View Settings';
$lang['error_invalidurl'] = '&Eacute;rv&eacute;nytelen URL <em>(tal&aacute;n m&aacute;r haszn&aacute;lj&aacute;k vagy &eacute;rv&eacute;nytelen karakterek vannak benne)</em>';
$lang['url'] = 'URL';
$lang['expired_searchable'] = 'Lej&aacute;rt cikkek megjelenhessenek a keres&eacute;si eredm&eacute;nyek k&ouml;z&ouml;tt';
$lang['helpshowall'] = 'Minden cikk mutat&aacute;sa, f&uuml;ggetlen&uuml;l a lej&aacute;rati d&aacute;tumt&oacute;l';
$lang['error_invaliddates'] = 'Valamelyik megadott d&aacute;tum &eacute;rv&eacute;nytelen volt';
$lang['notify_n_draft_items_sub'] = '%d darab &uacute;j cikk';
$lang['notify_n_draft_items'] = '%s darab nem publik&aacute;lt cikked van';
$lang['unlimited'] = 'Korl&aacute;tlan';
$lang['none'] = 'Nincs';
$lang['anonymous'] = 'Anonim';
$lang['unknown'] = 'Ismeretlen';
$lang['fesubmit_redirect'] = 'PageID vagy alias, amire &aacute;t kell ir&aacute;ny&iacute;tani, amikor &uacute;j cikk lett bek&uuml;ldve &#039;fesubmit&#039;-on kereszt&uuml;l';
$lang['allow_summary_wysiwyg'] = 'WYSIWYG szerkesztő haszn&aacute;lat&aacute;nak enged&eacute;lyez&eacute;se az &ouml;sszefoglal&oacute;ban';
$lang['title_browsecat_template'] = 'Rovat sablon szerkesztő b&ouml;ng&eacute;sz&eacute;se';
$lang['title_browsecat_sysdefault'] = 'Alap&eacute;rtelmezett rovatb&ouml;ng&eacute;sző sablon';
$lang['browsecattemplate'] = 'Rovat sablonok b&ouml;ng&eacute;sz&eacute;se';
$lang['error_filesize'] = 'Egy felt&ouml;lt&ouml;tt f&aacute;jl meghaladta a maxim&aacute;lisan enged&eacute;lyezett m&eacute;retet';
$lang['post_date_desc'] = 'Publik&aacute;l&aacute;s d&aacute;tuma szerint cs&ouml;kkenő';
$lang['post_date_asc'] = 'Publik&aacute;l&aacute;s d&aacute;tuma szerint n&ouml;vekvő';
$lang['expiry_date_desc'] = 'Lej&aacute;rat d&aacute;tuma szerint cs&ouml;kkenő';
$lang['expiry_date_asc'] = 'Lej&aacute;rat d&aacute;tuma szerint n&ouml;vekvő';
$lang['title_desc'] = 'C&iacute;m szerint cs&ouml;kkenő';
$lang['title_asc'] = 'C&iacute;m szerint n&ouml;vekvő';
$lang['status_desc'] = 'Cs&ouml;kkenő &aacute;llapot';
$lang['status_asc'] = 'N&ouml;vekvő &aacute;llapot';
$lang['fesubmit_status'] = 'A frontend-ről bek&uuml;ld&ouml;tt cikkik st&aacute;tusza';
$lang['error_invalidfiletype'] = 'Ilyen t&iacute;pus&uacute; f&aacute;jlt nem lehet felt&ouml;lteni.';
$lang['error_upload'] = 'A f&aacute;jl felt&ouml;lt&eacute;se k&ouml;zben hiba t&ouml;rt&eacute;nt.';
$lang['error_movefile'] = 'Nem siker&uuml;lt l&eacute;trehozni ezt a f&aacute;jlt: %s';
$lang['error_mkdir'] = 'Nem siker&uuml;lt l&eacute;trehozni ezt a f&aacute;jlt: %s';
$lang['expiry_interval'] = 'Cikkek lej&aacute;rati napjainak alap&eacute;rtelmezett sz&aacute;ma (ha a lej&aacute;rat enged&eacute;lyezve van)';
$lang['removed'] = 'T&ouml;r&ouml;lt.';
$lang['msg_contenttype_removed'] = 'A H&iacute;r t&iacute;pus&uacute; tartalom megszűnt. Helyette haszn&aacute;ld a {news} tag-et a megfelelő param&eacute;terekkel.';
$lang['delete_selected'] = 'Kijel&ouml;lt cikkek t&ouml;rl&eacute;se';
$lang['areyousure_deletemultiple'] = 'Biztos t&ouml;rl&ouml;d a kijel&ouml;lt cikkeket?\nEzt a műveletet nem lehet visszavonni!';
$lang['error_templatenamexists'] = 'Ilyen nevű sablon m&aacute;r van.';
$lang['error_noarticlesselected'] = 'Nincsenek kijel&ouml;lve cikkek.';
$lang['reassign_category'] = 'Rovat &aacute;t&aacute;ll&iacute;t&aacute;sa erre';
$lang['select'] = 'Kiv&aacute;laszt';
$lang['approve'] = 'St&aacute;tusz be&aacute;ll&iacute;t&aacute;sa &#039;Publik&aacute;lt&#039;-ra';
$lang['revert'] = 'St&aacute;tusz be&aacute;ll&iacute;t&aacute;sa &#039;Piszkozat&#039;-ra';
$lang['hide_summary_field'] = 'Az &ouml;sszefoglal&oacute; mező elrejt&eacute;se cikkek hozz&aacute;ad&aacute;sakor/m&oacute;dos&iacute;t&aacute;sakor';
$lang['textbox'] = 'Sz&ouml;vegmező';
$lang['checkbox'] = 'Jel&ouml;lőn&eacute;gyzet';
$lang['textarea'] = 'Sz&ouml;vegter&uuml;let';
$lang['file'] = 'F&aacute;jl';
$lang['auto_create_thumbnails'] = 'Automatikusan gener&aacute;ljunk miniatűr&ouml;ket az ilyen kiterjeszt&eacute;sű f&aacute;jlokhoz';
$lang['allowed_upload_types'] = 'Csak ilyen kiterjeszt&eacute;sű f&aacute;jlokat engedj&uuml;nk felt&ouml;lteni';
$lang['fielddefupdated'] = 'A mező defin&iacute;ci&oacute;j&aacute;t friss&iacute;tett&uuml;k';
$lang['editfielddef'] = 'Meződefin&iacute;ci&oacute; szerkeszt&eacute;se';
$lang['up'] = 'Fel';
$lang['down'] = 'Le';
$lang['fielddefdeleted'] = 'A meződefin&iacute;ci&oacute;t t&ouml;r&uuml;lt&uuml;k';
$lang['nameexists'] = 'Ilyen nevű mező m&aacute;r l&eacute;tezik.';
$lang['notanumber'] = 'A maximum hossznak numerikusnak kell lennie';
$lang['fielddef'] = 'Meződefin&iacute;ci&oacute;';
$lang['fielddefadded'] = 'A meződefin&iacute;ci&oacute;t sikeresen hozz&aacute;adtuk';
$lang['public'] = 'Publikus';
$lang['type'] = 'T&iacute;pus';
$lang['info_maxlength'] = 'A maxim&aacute;lis hossz csak sz&ouml;vegbeviteli mezőkre &eacute;rv&eacute;nyes';
$lang['maxlength'] = 'Maxim&aacute;lis hossz';
$lang['addfielddef'] = 'Mező defin&iacute;ci&oacute; hozz&aacute;ad&aacute;sa';
$lang['customfields'] = 'Mező defin&iacute;ci&oacute;k';
$lang['deprecated'] = 'nem t&aacute;mogatott';
$lang['subject_newnews'] = 'Az &uacute;j cikket publik&aacute;ltuk';
$lang['email_subject'] = 'A kimenő lev&eacute;l t&aacute;rgya';
$lang['email_template'] = 'A lev&eacute;l form&aacute;tuma';
$lang['formsubmit_emailaddress'] = 'Az email c&iacute;m, ahova &eacute;rtes&iacute;t&eacute;st k&uuml;ld&uuml;nk a cikk meg&iacute;r&aacute;s&aacute;r&oacute;l';
$lang['extra'] = 'Extra ';
$lang['uploadscategory'] = 'Felt&ouml;lt&eacute;s kateg&oacute;ria';
$lang['title_available_templates'] = 'El&eacute;rhető sablonok';
$lang['resettodefault'] = 'Alap&eacute;rtelmezett &eacute;rt&eacute;kek vissza&aacute;ll&iacute;t&aacute;sa';
$lang['title_form_template'] = 'Form sablon szerkesztő';
$lang['title_detail_template'] = 'R&eacute;szletes sablon szerkesztő';
$lang['title_summary_template'] = '&Ouml;sszefoglal&oacute; sablon szerkesztő';
$lang['prompt_templatename'] = 'Sablon neve';
$lang['prompt_template'] = 'Sablon forr&aacute;sa';
$lang['title_form_sysdefault'] = 'Alap&eacute;rtelmezett form sablon';
$lang['title_summary_sysdefault'] = 'Alap&eacute;rtelmezett &ouml;sszefoglal&oacute; sablon';
$lang['title_detail_sysdefault'] = 'Alap&eacute;rtelmezett r&eacute;szletes sablon';
$lang['info_sysdefault2'] = '<strong>Note:</strong> This tab contains text areas to allow you to edit a set of templates that are displayed when you create a &#039;new&#039; summary, detail, or form template.  Changing content in this tab, and clicking &#039;submit&#039; will <strong>not effect any current displays</strong>.';
$lang['info_sysdefault'] = '<em>(az alkalmazott sablon, amikor &uacute;j sablon ker&uuml;l kiv&aacute;laszt&aacute;sra)</em>';
$lang['template'] = 'Sablon';
$lang['prompt_name'] = 'N&eacute;v';
$lang['prompt_default'] = 'Alap&eacute;rtelmezett';
$lang['prompt_newtemplate'] = '&Uacute;j sablon l&eacute;trehoz&aacute;sa';
$lang['help_pagelimit'] = 'Egy oldalon megjelen&iacute;thető elemek maxim&aacute;lis sz&aacute;ma.  Ha ez a param&eacute;ter nincs megadva, akkor minden cikk meg lesz mutatva.  Ha viszont megadtad, akkor linkekkel &eacute;s sz&ouml;veggel lesz jelezve, hogy merre lehet lapozni (ha egy oldalra nem f&eacute;r el egyszerre az &ouml;sszes cikk)';
$lang['prompt_page'] = 'Oldal';
$lang['firstpage'] = '<<';
$lang['prevpage'] = '<';
$lang['nextpage'] = '>';
$lang['lastpage'] = '>>';
$lang['prompt_of'] = 'ennyiből:';
$lang['prompt_pagelimit'] = 'Oldal limit';
$lang['prompt_sorting'] = 'Rendez&eacute;si szempont';
$lang['title_filter'] = 'Szűrők';
$lang['published'] = 'Publik&aacute;lt';
$lang['draft'] = 'Piszkozat';
$lang['expired'] = 'Lej&aacute;rt';
$lang['author'] = 'Szerző';
$lang['sysdefaults'] = 'Alap&eacute;rtelmezett &eacute;rt&eacute;kek vissza&aacute;ll&iacute;t&aacute;sa';
$lang['restoretodefaultsmsg'] = 'Ez a művelet vissza&aacute;ll&iacute;tja a sablon tartalm&aacute;t az alap&eacute;rtelmezett &eacute;rt&eacute;kekre. Biztosan folytatni akarod?';
$lang['addarticle'] = 'Cikk hozz&aacute;ad&aacute;sa';
$lang['articleadded'] = 'A cikket sikeresen hozz&aacute;adtuk.';
$lang['articleupdated'] = 'A cikket sikeresen friss&iacute;tett&uuml;k.';
$lang['articledeleted'] = 'A cikket sikeresen t&ouml;r&ouml;lt&uuml;k.';
$lang['addcategory'] = 'Rovat hozz&aacute;ad&aacute;sa';
$lang['categoryadded'] = 'A rovatot sikeresen hozz&aacute;adtuk.';
$lang['categoryupdated'] = 'A rovatot sikeresen friss&iacute;tet&uuml;k.';
$lang['categorydeleted'] = 'A rovatot sikeresen t&ouml;r&ouml;lt&uuml;k.';
$lang['addnewsitem'] = 'H&iacute;r hozz&aacute;ad&aacute;sa';
$lang['allcategories'] = 'Minden rovat';
$lang['allentries'] = 'Minden bejegyz&eacute;s';
$lang['areyousure'] = 'Biztosan t&ouml;r&ouml;lni akarod?';
$lang['articles'] = 'Cikkek';
$lang['cancel'] = 'M&eacute;gsem';
$lang['category'] = 'Rovat';
$lang['categories'] = 'Rovatok';
$lang['default_category'] = 'Alap&eacute;rtelmezett rovat';
$lang['content'] = 'Tartalom';
$lang['dateformat'] = '%s nem felel meg az &eacute;&eacute;&eacute;&eacute;-hh-nn &oacute;&oacute;:pp:mm form&aacute;tum le&iacute;r&aacute;snak';
$lang['delete'] = 'T&ouml;rl&eacute;s';
$lang['description'] = 'Cikkek hozz&aacute;ad&aacute;sa, szerkeszt&eacute;se &eacute;s t&ouml;rl&eacute;se';
$lang['formtemplate'] = 'Form sablonok';
$lang['detailtemplate'] = 'R&eacute;szletes sablon';
$lang['default_templates'] = 'Alap&eacute;rtelmezett sablonok';
$lang['detailtemplateupdated'] = 'A friss&iacute;tett r&eacute;szletes sablont sikeresen kimentett&uuml;k az adatb&aacute;zisba.';
$lang['displaytemplate'] = 'Megjelen&iacute;t&eacute;si sablon';
$lang['edit'] = 'Szerkeszt&eacute;s';
$lang['enddate'] = 'Lej&aacute;rat d&aacute;tuma';
$lang['endrequiresstart'] = 'Lej&aacute;rati d&aacute;tum megad&aacute;s&aacute;nak csak &uacute;gy van &eacute;rtelme, ha kezdőd&aacute;tumot is megad';
$lang['entries'] = '%s bejegyz&eacute;sek';
$lang['status'] = 'St&aacute;tusz';
$lang['expiry'] = 'Lej&aacute;rat';
$lang['filter'] = 'Szűrő';
$lang['more'] = 'tov&aacute;bb';
$lang['category_label'] = 'Rovat:';
$lang['author_label'] = 'Bek&uuml;ldte:';
$lang['moretext'] = 'Tov&aacute;bbi sz&ouml;veg';
$lang['name'] = 'N&eacute;v';
$lang['news'] = 'H&iacute;rek';
$lang['news_return'] = 'Vissza';
$lang['newcategory'] = '&Uacute;j rovat';
$lang['needpermission'] = 'Sz&uuml;ks&eacute;g van a(z) \&#039;%s\&#039; jogosults&aacute;gra ezen művelet elv&eacute;gz&eacute;s&eacute;hez';
$lang['nocategorygiven'] = 'A rovat nincs megadva';
$lang['startdatetoolate'] = 'A kezdőd&aacute;tum t&uacute;l k&eacute;sői (a lej&aacute;ratn&aacute;l k&eacute;sőbbi?)';
$lang['nocontentgiven'] = 'A tartalom nincs kit&ouml;ltve';
$lang['noitemsfound'] = '<strong>Nincsenek</strong> elemek ebben a kateg&oacute;ri&aacute;ban: %s';
$lang['nopostdategiven'] = 'A publik&aacute;l&aacute;s d&aacute;tuma nincs megadva';
$lang['note'] = '<em>Megjegyz&eacute;s:</em> A d&aacute;tumokat \&#039;&eacute;&eacute;&eacute;&eacute;-hh-nn &oacute;&oacute;:pp:mm\&#039; form&aacute;ban kell megadni.';
$lang['notitlegiven'] = 'Nincs megadva a c&iacute;m';
$lang['nonamegiven'] = 'Nincs megadva a n&eacute;v';
$lang['numbertodisplay'] = 'Megmutathat&oacute; elemek sz&aacute;ma (ha nincs megadva, akkor minden cikk meg lesz mutatva)';
$lang['print'] = 'Nyomtat&aacute;s';
$lang['postdate'] = 'Publik&aacute;l&aacute;s d&aacute;tuma';
$lang['postinstall'] = 'Győződj meg r&oacute;la, hogy a \&quot;Modify News\&quot; jogosults&aacute;ggal rendelkezik az &ouml;sszes olyan felhaszn&aacute;l&oacute;, aki cikkeket fog adminisztr&aacute;lni.';
$lang['selectcategory'] = 'V&aacute;lassz rovatot';
$lang['showchildcategories'] = 'Gyermekrovatok mutat&aacute;sa';
$lang['sortascending'] = 'N&ouml;vekvő rendez&eacute;s';
$lang['startdate'] = 'Kezdet d&aacute;tuma';
$lang['startoffset'] = 'Az n. elemn&eacute;l kezdj&uuml;k a megjelen&iacute;t&eacute;st';
$lang['startrequiresend'] = 'Kezdőd&aacute;tum megad&aacute;s&aacute;nak csak &uacute;gy van &eacute;rtelme, ha lej&aacute;rati d&aacute;tumot is megad';
$lang['submit'] = 'Elk&uuml;ld';
$lang['summary'] = '&Ouml;sszefoglal&oacute;';
$lang['summarytemplate'] = '&Ouml;sszefoglal&oacute; sablon';
$lang['summarytemplateupdated'] = 'Az &ouml;sszefoglal&oacute; sablont sikeresen friss&iacute;tett&uuml;k.';
$lang['title'] = 'C&iacute;m';
$lang['options'] = 'Opci&oacute;k';
$lang['optionsupdated'] = 'Az opci&oacute;kat sikeresen friss&iacute;tett&uuml;k.';
$lang['useexpiration'] = 'Lej&aacute;rati d&aacute;tum haszn&aacute;lata';
$lang['eventdesc-NewsArticleAdded'] = 'Akkor k&uuml;ldj&uuml;k, amikor &uacute;j cikk j&ouml;n l&eacute;tre.';
$lang['eventhelp-NewsArticleAdded'] = '<p>Sent when an article is added.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;news_id\&quot; - Id of the news article</li>
<li>\&quot;category_id\&quot; - Id of the category for this article</li>
<li>\&quot;title\&quot; - Title of the article</li>
<li>\&quot;content\&quot; - Content of the article</li>
<li>\&quot;summary\&quot; - Summary of the article</li>
<li>\&quot;status\&quot; - Status of the article (\&quot;draft\&quot; or \&quot;publish\&quot;)</li>
<li>\&quot;start_time\&quot; - Date the article should start being displayed</li>
<li>\&quot;end_time\&quot; - Date the article should stop being displayed</li>
</ul>
';
$lang['eventdesc-NewsArticleEdited'] = 'Akkor k&uuml;ldj&uuml;k, amikor egy cikk megv&aacute;ltozik.';
$lang['eventhelp-NewsArticleEdited'] = '<p>Sent when an article is edited.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;news_id\&quot; - Id of the news article</li>
<li>\&quot;category_id\&quot; - Id of the category for this article</li>
<li>\&quot;title\&quot; - Title of the article</li>
<li>\&quot;content\&quot; - Content of the article</li>
<li>\&quot;summary\&quot; - Summary of the article</li>
<li>\&quot;status\&quot; - Status of the article (\&quot;draft\&quot; or \&quot;publish\&quot;)</li>
<li>\&quot;start_time\&quot; - Date the article should start being displayed</li>
<li>\&quot;end_time\&quot; - Date the article should stop being displayed</li>
</ul>
';
$lang['eventdesc-NewsArticleDeleted'] = 'Akkor k&uuml;ldj&uuml;k, amikor egy cikket t&ouml;r&ouml;lnek.';
$lang['eventhelp-NewsArticleDeleted'] = '<p>Sent when an article is deleted.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;news_id\&quot; - Id of the news article</li>
</ul>
';
$lang['eventdesc-NewsCategoryAdded'] = 'Akkor k&uuml;ldj&uuml;k, amikor egy rovatot felvesznek.';
$lang['eventhelp-NewsCategoryAdded'] = '<p>Sent when a category is added.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;category_id\&quot; - Id of the news categpry</li>
<li>\&quot;name\&quot; - Name of the news category</li>
</ul>
';
$lang['eventdesc-NewsCategoryEdited'] = 'Akkor k&uuml;ldj&uuml;k, amikor egy rovatot m&oacute;dos&iacute;tanak.';
$lang['eventhelp-NewsCategoryEdited'] = '<p>Sent when a category is edited.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;category_id\&quot; - Id of the news categpry</li>
<li>\&quot;name\&quot; - Name of the news category</li>
</ul>
';
$lang['eventdesc-NewsCategoryDeleted'] = 'Akkor k&uuml;ldj&uuml;k, amikor egy rovatot t&ouml;r&ouml;lnek.';
$lang['eventhelp-NewsCategoryDeleted'] = '<p>Sent when a category is deleted.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;category_id\&quot; - Id of the news categpry</li>
</ul>
';
$lang['help_articleid'] = 'Ez a param&eacute;ter csak a r&eacute;szletes n&eacute;zetben &eacute;rtelmezett. Megadhat&oacute; vele, hogy melyik cikk legyen l&aacute;that&oacute; a r&eacute;szletes n&eacute;zetben. Ha -1-et adsz meg, akkor a rendszer a legfrissebb, nem lej&aacute;rt, publik&aacute;lt st&aacute;tusz&uacute; cikket fogja megjelen&iacute;teni.';
$lang['helpnumber'] = 'A maxim&aacute;lisan megjelen&iacute;thető elemek sz&aacute;ma -- ha nem adod meg, minden elem meg lesz mutatva';
$lang['helpstart'] = 'Az n. elemn&eacute;l kezdj&uuml;k a megjelen&iacute;t&eacute;st -- &uuml;resen hagyva az első elemn&eacute;l kezdődik  ';
$lang['helpcategory'] = 'Csak az adott rovat h&iacute;reit jelen&iacute;ts&uuml;k meg. A n&eacute;v ut&aacute;n a * karaktert alkalmazva a gyermekrovatok is megmutathat&oacute;k. T&ouml;bb rovat is megadhat&oacute;, vesszővel elv&aacute;lasztva. &Uuml;resen hagyva minden rovat meg lesz mutatva.';
$lang['helpmoretext'] = 'A sz&ouml;veg, amit akkor jelen&iacute;t&uuml;nk meg, ha a h&iacute;r hosszabb, mint az &ouml;sszefoglal&oacute; hossza. Alap&eacute;rtelmez&eacute;sben ez \&quot;tov&aacute;bb...\&quot;';
$lang['helpsummarytemplate'] = 'K&uuml;l&ouml;n sablon haszn&aacute;lata az &ouml;sszefoglal&oacute; megjelen&iacute;t&eacute;s&eacute;hez. L&eacute;teznie kell a modules/News/templates alatt.';
$lang['helpformtemplate'] = 'Adatb&aacute;zis sablon haszn&aacute;lata a cikk bek&uuml;ldő form megjelen&iacute;t&eacute;s&eacute;hez. Ennek a sablonnak l&eacute;teznie kell &eacute;s l&aacute;that&oacute;nak kell lennie az admin fel&uuml;let sablon panelj&aacute;n, de nem kell alap&eacute;rtelmezettnek lennie. Ha ez a param&eacute;ter nincs megadva, akkor az aktu&aacute;lis alap&eacute;rtelmezett sablont fogja haszn&aacute;lni a rendszer.';
$lang['helpbrowsecattemplate'] = 'Adatb&aacute;zis sablon haszn&aacute;lata a rovat b&ouml;ng&eacute;sző megjelen&iacute;t&eacute;s&eacute;hez. Ennek a sablonnak l&eacute;teznie kell &eacute;s l&aacute;that&oacute;nak kell lennie az admin fel&uuml;let Rovat sablonok panelj&aacute;n, de nem kell alap&eacute;rtelmezettnek lennie. Ha ez a param&eacute;ter nincs megadva, akkor az aktu&aacute;lis alap&eacute;rtelmezett sablont fogja haszn&aacute;lni a rendszer.';
$lang['helpdetailtemplate'] = 'K&uuml;l&ouml;n sablon haszn&aacute;lata a cikk megjelen&iacute;t&eacute;s&eacute;hez. L&eacute;teznie kell a modules/News/templates alatt.';
$lang['helpsortby'] = 'A rendez&eacute;s alapja.  V&aacute;laszt&aacute;si lehetős&eacute;gek: \&quot;news_date\&quot;, \&quot;summary\&quot;, \&quot;news_data\&quot;, \&quot;news_category\&quot;, \&quot;news_title\&quot;.  Alap&eacute;rtelmez&eacute;sben ez a \&quot;news_date\&quot;.';
$lang['helpsortasc'] = 'Az elemek n&ouml;vekvő sorrendben val&oacute; megmutat&aacute;sa.';
$lang['helpdetailpage'] = 'Az oldal, ahol a cikkeknek meg kell jelenni&uuml;k. Ez lehet oldal alias vagy egy azonos&iacute;t&oacute;. Arra haszn&aacute;lhat&oacute;, hogy a cikk sz&ouml;vege az &ouml;sszefoglal&oacute;t&oacute;l elt&eacute;rő sablon szerint lehessen megjelen&iacute;tve.';
$lang['helpshowarchive'] = 'Csak lej&aacute;rt cikkek mutat&aacute;sa.';
$lang['helpbrowsecat'] = 'Rovatok b&ouml;ng&eacute;sz&eacute;se.';
$lang['helpaction'] = 'Override the default action.  Possible values are &#039;default&#039; to display the summary view, and &#039;fesubmit&#039; to display the frontend form for allowing users to submit news articles on the front end.';
$lang['help'] = '	<h3>What does this do?</h3>
	<p>News is a module for displaying news events on your page, similar to a blog style, except with more features!.  When the module is installed, a News admin page is added to administration menu that will allow you to select or add a news category.  Once a news category is created or selected, a list of news items for that category will be displayed.  From here, you can add, edit or delete news items for that category.</p>
	<h3>Security</h3>
	<p>The user must belong to a group with the \&#039;Modify News\&#039; permission in order to add, edit, or delete News entries.</p>
	<p>In order to edit the layout templates, the user must belong to a group with the \&#039;Modify Templates\&#039; permission.</p>
	<p>In order to edit the global news preferences, the user must belong to a group with the \&#039;Modify Site Preferences\&#039; permission.</p>
	<h3>How do I use it?</h3>
	<p>The easiest way to use it is in conjunction with the cms_module tag.  This will insert the module into your template or page anywhere you wish, and display news items.  The code would look something like: <code>{cms_module module=\&quot;news\&quot; number=\&quot;5\&quot; category=\&quot;beer\&quot;}</code></p>';
$lang['utma'] = '156861353.1637687971.1300706706.1300706706.1300706706.1';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
$lang['utmz'] = '156861353.1300706706.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
?>